Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/boringssl.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDavid Benjamin <davidben@chromium.org>2015-02-17 03:16:46 +0300
committerAdam Langley <agl@google.com>2015-02-17 23:51:22 +0300
commited7c4751542d81f86161fd1c3598c189fc976f58 (patch)
treee21c8488dd3632ada85937e5d724b29b0377e36d /include/openssl/ssl3.h
parenta54e2e85ee64a4192c85c8c6250e3879c81248e4 (diff)
Rename cutthrough to False Start.
False Start is the name it's known by now. Deprecate the old API and expose new ones with the new name. Change-Id: I32d307027e178fd7d9c0069686cc046f75fdbf6f Reviewed-on: https://boringssl-review.googlesource.com/3481 Reviewed-by: Adam Langley <agl@google.com>
Diffstat (limited to 'include/openssl/ssl3.h')
-rw-r--r--include/openssl/ssl3.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/openssl/ssl3.h b/include/openssl/ssl3.h
index de3b96cf..ce53801d 100644
--- a/include/openssl/ssl3.h
+++ b/include/openssl/ssl3.h
@@ -485,9 +485,9 @@ typedef struct ssl3_state_st {
* be updated. It is only needed for EAP-FAST, which we don't support. */
uint8_t new_mac_secret_size;
- /* Client-only: cutthrough_complete is one if there is a pending handshake,
- * but cut-through is completed so the client may write data. */
- char cutthrough_complete;
+ /* Client-only: in_false_start is one if there is a pending handshake in
+ * False Start. The client may write data at this point. */
+ char in_false_start;
} tmp;
/* Connection binding to prevent renegotiation attacks */
@@ -530,7 +530,7 @@ typedef struct ssl3_state_st {
/* client */
/* extra state */
#define SSL3_ST_CW_FLUSH (0x100 | SSL_ST_CONNECT)
-#define SSL3_ST_CUTTHROUGH_COMPLETE (0x101 | SSL_ST_CONNECT)
+#define SSL3_ST_FALSE_START (0x101 | SSL_ST_CONNECT)
/* write to server */
#define SSL3_ST_CW_CLNT_HELLO_A (0x110 | SSL_ST_CONNECT)
#define SSL3_ST_CW_CLNT_HELLO_B (0x111 | SSL_ST_CONNECT)